Learn R Programming

MultiATSM (version 0.3.6)

A0N_MLEdensity_WOE__jointQ_Bootstrap: Compute the maximum likelihood function (joint Q models) - Bootstrap version

Description

Compute the maximum likelihood function (joint Q models) - Bootstrap version

Usage

A0N_MLEdensity_WOE__jointQ_Bootstrap(
  K1XQ,
  r0,
  SSZ,
  K0Z,
  K1Z,
  se,
  Gy.0,
  mat,
  Y,
  Z,
  P,
  Wpca,
  We,
  WpcaFull,
  dt,
  Economies,
  FactorLabels,
  ModelType,
  residBS,
  MaxEigen,
  GVARinputs,
  JLLinputs,
  nargout
)

Arguments

K1XQ

risk-neutral feedback matrix (NxN)

r0

long-run interest rate (scalar)

SSZ

variance-covariance matrix (KxK)

K0Z

intercept from the P-dynamics (Kx1)

K1Z

feedback matrix from the P-dynamics (KxK)

se

Variance of the portfolio of yields observed with error (scalar)

Gy.0

matrix of contemporaneous terms from the P-dynamics (KxK)

mat

vector of maturities (in years) of yields used in estimation (J x 1)

Y

matrix of yields used in estimation (J x T)

Z

complete set of spanned and unspanned factors (KxT)

P

complete set of spanned factors (NxT)

Wpca

matrix of weights of the portfolios observed without errors (NxJ)

We

matrix of weights of the portfolios observed with errors ((J-N)xJ)

WpcaFull

composite matrix of weights the portfolios observed with and without errors

dt

time interval unit of the model (scalar). For instance, if data is (i) monthly, dt <- 12; (ii) quarterly, dt <- 4; (iii) yearly, dt <- 1.

Economies

a string-vector containing the names of the economies which are part of the economic system

FactorLabels

string-list based which contains the labels of all the variables present in the model

ModelType

feasible options are (i) "VAR jointQ", (ii) "GVAR jointQ" or (iii) "JLL jointSigma"

residBS

index of the re-ordered bootstrap residuals

MaxEigen

largest eigenvalue under the P-dynamics

GVARinputs

if the model chosen is the "GVAR sepQ", "GVARinputs" should be specified (see "GVAR" function )

JLLinputs

if the model chosen is the "JLL jointSigma". "JLLinputs" should be specified (see "JLL" function)

nargout

if nargout== 1: provides only the values of the likelihood; if nargout== 2: complete ATSM outputs

References

This function is modified version of the "A0N_MLEdensity_WOE" function by Le and Singleton (2018).
"A Small Package of Matlab Routines for the Estimation of Some Term Structure Models."
(Euro Area Business Cycle Network Training School - Term Structure Modelling). Available at: https://cepr.org/40029