Learn R Programming

MultiATSM (version 0.3.6)

A0N__computeBnAn_sepQ: Compute the cross-section loadings of yields of a canonical A0_N model ("sep Q" models)

Description

Compute the cross-section loadings of yields of a canonical A0_N model ("sep Q" models)

Usage

A0N__computeBnAn_sepQ(mat, K1XQ, dX, r0, SSX)

Value

List containing:

  • Intercept (Jx1)

  • slope (JxN)

  • the betan (JX1, part of the intercepts unrelated to the long run risk neutral mean r0) coefficients of a canonical A_0(N).

Arguments

mat

vector of maturities (J x 1). Maturities are in multiples of the discrete interval used in the model

K1XQ

risk neutral feedback matrix (N x N)

dX

state loadings for the one-period rate (1xN). Default is a vector of ones

r0

the long run risk neutral mean of the short rate (scalar)

SSX

the covariance matrix of the errors (N x N)

References

  • This function is based on the "A0N__computeBnAn" function by Le and Singleton (2018).
    "A Small Package of Matlab Routines for the Estimation of Some Term Structure Models."
    (Euro Area Business Cycle Network Training School - Term Structure Modelling). Available at: https://cepr.org/40029

  • Dai and Singleton (2000). "Specification Analysis of Affine Term Structure Models" (The Journal of Finance)