IdxAllSpanned: Find the indexes of the spanned factors
Description
Find the indexes of the spanned factors
Usage
IdxAllSpanned(ModelType, FactorLabels, Economies)
Arguments
- ModelType
string-vector containing the label of the model to be estimated
- FactorLabels
string-list based which contains the labels of all the variables present in the model
- Economies
string-vector containing the names of the economies which are part of the economic system