Learn R Programming

MultiATSM (version 0.3.6)

MLEdensity_jointQ_sepSigma: Compute the maximum likelihood function ("joint Q" models for separate Sigma estimation)

Description

Compute the maximum likelihood function ("joint Q" models for separate Sigma estimation)

Usage

MLEdensity_jointQ_sepSigma(
  K1XQ,
  r0,
  SSZ,
  K0Z,
  K1Z,
  se,
  Gy.0,
  mat,
  Y,
  Z,
  P,
  Wpca,
  We,
  WpcaFull,
  dt,
  Economies,
  FactorLabels,
  ModelType,
  JLLinputs,
  nargout
)

Arguments

K1XQ

risk-neutral feedback matrix (NxN)

r0

long-run interest rate (scalar)

SSZ

variance-covariance matrix (KxK)

K0Z

intercept from the P-dynamics (Kx1)

K1Z

feedback matrix from the P-dynamics (KxK)

se

Variance of the portfolio of yields observed with error (scalar)

Gy.0

matrix of contemporaneous terms from the P-dynamics (KxK)

mat

vector of maturities (in years) of yields used in estimation (J x 1)

Y

matrix of yields used in estimation (J x T)

Z

complete set of spanned and unspanned factors (KxT)

P

complete set of spanned factors (NxT)

Wpca

matrix of weights of the portfolios observed without errors (NxJ)

We

matrix of weights of the portfolios observed with errors ((J-N)xJ)

WpcaFull

composite matrix of weights the portfolios observed with and without errors

dt

time interval unit of the model (scalar). For instance, if data is (i) monthly, dt <- 12; (ii) quarterly, dt <- 4; (iii) yearly, dt <- 1.

Economies

Set of economies that are part of the economic system (vector of text)

FactorLabels

string-list based which contains the labels of all the variables present in the model

ModelType

feasible options are (i) "JLL original" or (ii) "JLL NoDomUnit"

JLLinputs

if the model chosen is the "JLL jointSigma", "JLLinputs" should be specified (see "JLL" function)

nargout

if nargout== 1: provides only the values of the likelihood; if nargout== 2: complete ATSM outputs

References

This function is an extended version of the "A0N_MLEdensity_WOE" function by Le and Singleton (2018).
"A Small Package of Matlab Routines for the Estimation of Some Term Structure Models."
(Euro Area Business Cycle Network Training School - Term Structure Modelling). Available at: https://cepr.org/40029