powered by
Compute the country-specific spanned factors
Spanned_Factors(Yields, Economies, N)
Matrix containing the N spanned for all the countries of the system (CJ xT)
matrix (J x T), where J - the number of maturities and T - time series length
C-dimensional string-vector containing the names of the economies which are part of the economic system
scalar: desired number of spanned factors (maximum number allowed is N= J)
data(CM_Yields) Economies <- c("China", "Brazil", "Mexico", "Uruguay") N <- 3 Spanned_Factors(Yields, Economies, N)
Run the code above in your browser using DataLab