Compute the maximum likelihood function (joint Q models) - Bootstrap version
A0N_MLEdensity_WOE__jointQ_Bootstrap(
K1XQ,
r0,
SSZ,
K0Z,
K1Z,
se,
Gy.0,
mat,
Y,
Z,
P,
Wpca,
We,
WpcaFull,
dt,
Economies,
FactorLabels,
ModelType,
residBS,
MaxEigen,
GVARinputs,
JLLinputs,
nargout
)risk-neutral feedback matrix (NxN)
long-run interest rate (scalar)
variance-covariance matrix (KxK)
intercept from the P-dynamics (Kx1)
feedback matrix from the P-dynamics (KxK)
Variance of the portfolio of yields observed with error (scalar)
matrix of contemporaneous terms from the P-dynamics (KxK)
vector of maturities (in years) of yields used in estimation (J x 1)
matrix of yields used in estimation (J x T)
complete set of spanned and unspanned factors (KxT)
complete set of spanned factors (NxT)
matrix of weights of the portfolios observed without errors (NxJ)
matrix of weights of the portfolios observed with errors ((J-N)xJ)
composite matrix of weights the portfolios observed with and without errors
time interval unit of the model (scalar). For instance, if data is (i) monthly, dt <- 12; (ii) quarterly, dt <- 4; (iii) yearly, dt <- 1.
a string-vector containing the names of the economies which are part of the economic system
string-list based which contains the labels of all the variables present in the model
feasible options are (i) "VAR jointQ", (ii) "GVAR jointQ" or (iii) "JLL jointSigma"
index of the re-ordered bootstrap residuals
largest eigenvalue under the P-dynamics
if the model chosen is the "GVAR sepQ", "GVARinputs" should be specified (see "GVAR" function )
if the model chosen is the "JLL jointSigma". "JLLinputs" should be specified (see "JLL" function)
if nargout== 1: provides only the values of the likelihood; if nargout== 2: complete ATSM outputs
This function is modified version of the "A0N_MLEdensity_WOE" function by Le and Singleton (2018).
"A Small Package of Matlab Routines for the Estimation of Some Term Structure Models."
(Euro Area Business Cycle Network Training School - Term Structure Modelling).
Available at: https://cepr.org/40029