Compute the cross-section loadings of yields of a canonical A0_N model ("joint Q" models)
A0N__computeBnAn_jointQ(mat, K1XQ, dX, r0, SSX, Economies)List containing:
Intercept (Jx1)
slope (JxN)
the betan (JX1, part of the intercepts unrelated to the long run risk neutral mean r0) coefficients of a canonical A_0(N).
vector of maturities (J x 1). Maturities are in multiples of the discrete interval used in the model
risk neutral feedback matrix (N x N)
state loadings for the one-period rate (1xN). Default is a vector of ones
the long run risk neutral mean of the short rate (scalar)
the covariance matrix of the errors (N x N)
Set of economies that are part of the economic system (vector of text)
This function is an extended version of the "A0N__computeBnAn" function by Le and Singleton (2018).
"A Small Package of Matlab Routines for the Estimation of Some Term Structure Models."
(Euro Area Business Cycle Network Training School - Term Structure Modelling).
Available at: https://cepr.org/40029